==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/StackedSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineSeriesDescription } from "./StackedSplineSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineSeriesDescriptionMetadata.a == null) {
                StackedSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineSeriesDescriptionMetadata.c(StackedSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(StackedSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineSeriesDescriptionMetadata.b(a);
            a.ad("StackedSplineSeries", () => new StackedSplineSeriesDescription());
            a.ac("StackedSplineSeries", StackedSplineSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSplineSeriesDescriptionMetadata, 'StackedSplineSeriesDescriptionMetadata');
    StackedSplineSeriesDescriptionMetadata.a = null;
    return StackedSplineSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/StackedSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineSeriesDescription } from "./StackedSplineSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineSeriesDescriptionMetadata.a == null) {
                StackedSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineSeriesDescriptionMetadata.c(StackedSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(StackedSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineSeriesDescriptionMetadata.b(a);
            a.ae("StackedSplineSeries", () => new StackedSplineSeriesDescription());
            a.ad("StackedSplineSeries", StackedSplineSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSplineSeriesDescriptionMetadata, 'StackedSplineSeriesDescriptionMetadata');
    StackedSplineSeriesDescriptionMetadata.a = null;
    return StackedSplineSeriesDescriptionMetadata;
})();
